@@ -39,6 +39,7 @@ extensions = [
     "sphinx_mdinclude",
     "sphinx_immaterial",
     "sphinx_immaterial.apidoc.python.apigen",
+    "sphinx.ext.linkcode"
     # "sphinx_search.extension",
 ]
 autoapi_dirs = ["../../elementy"]
@@ -60,6 +61,20 @@ intersphinx_mapping = {
 }
 intersphinx_disabled_domains = ["std"]
 
+
+def linkcode_resolve(domain, info):
+    if domain != "py":
+        return None
+    if not info["module"]:
+        return None
+    filename = info["module"].replace(".", "/")
+    if filename == "elementy":
+        filename += "/__init__"
+    return (
+        "https://github.com/Robert-Forrest/elementy/blob/main/%s.py" % filename
+    )
+
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
 
